education\_math\_homework\_generator package
============================================

Submodules
----------

education\_math\_homework\_generator.gen\_add\_subtract module
--------------------------------------------------------------

.. automodule:: education_math_homework_generator.gen_add_subtract
    :members:
    :undoc-members:
    :show-inheritance:

education\_math\_homework\_generator.gen\_number\_line module
-------------------------------------------------------------

.. automodule:: education_math_homework_generator.gen_number_line
    :members:
    :undoc-members:
    :show-inheritance:

education\_math\_homework\_generator.setup module
-------------------------------------------------

.. automodule:: education_math_homework_generator.setup
    :members:
    :undoc-members:
    :show-inheritance:

education\_math\_homework\_generator.util module
------------------------------------------------

.. automodule:: education_math_homework_generator.util
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: education_math_homework_generator
    :members:
    :undoc-members:
    :show-inheritance:
